changeset 80025:f162659514ca

Comment changes.
author Richard M. Stallman <rms@gnu.org>
date Mon, 04 Feb 2008 16:54:05 +0000
parents 9231505e5076
children 4c5a74fdf2d2
files lisp/emacs-lisp/edebug.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/emacs-lisp/edebug.el	Mon Feb 04 16:36:48 2008 +0000
+++ b/lisp/emacs-lisp/edebug.el	Mon Feb 04 16:54:05 2008 +0000
@@ -1496,7 +1496,7 @@
     (cond
      ((symbolp head)
       (cond
-       ((null head) nil) ; () is legal.
+       ((null head) nil) ; () is valid.
        ((eq head 'interactive-p)
 	;; Special case: replace (interactive-p) with variable
 	(setq edebug-def-interactive 'check-it)
@@ -2076,7 +2076,7 @@
    ;; doesn't handle (a . ,b).  The straightforward fix:
    ;;   (backquote-form . [&or nil backquote-form])
    ;; uses up too much stack space.
    ;; Note that `(foo . ,@bar) is not legal, so we don't need to handle it.
    (backquote-form [&rest [&not ","] backquote-form]
 		   . [&or nil backquote-form])
    ;; If you use dotted forms in backquotes, replace the previous line
@@ -2076,7 +2076,7 @@
    ;;   (backquote-form . [&or nil backquote-form])
    ;; uses up too much stack space.
-   ;; Note that `(foo . ,@bar) is not legal, so we don't need to handle it.
+   ;; Note that `(foo . ,@bar) is not valid, so we don't need to handle it.
    (backquote-form [&rest [&not ","] backquote-form]
 		   . [&or nil backquote-form])